@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2011  Tom Cato Amundsen
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -50,6 +50,9 @@ class SolfegeOptionParser(optparse.OptionParser):
             help=_('Show GtkWarnings and PangoWarnings in the traceback window.'))
         self.add_option('-P', dest="profile",
             help=_('Start with <profile>. Create the profile if it does not exist.'))
+        self.add_option('--make-screenshots', action='store_true',
+            dest='screenshots',
+            help=_("Create or update the screenshots for the user manual. Intended for developers of this program."))
     def print_help(self, outfile=None):
         if outfile is None:
             outfile = sys.stdout
